/*
  OLIMEXINO-32U4 + MOD-BT
  
  This example configures the OLIMEXINO-32U4 board
  to read and print the characters of MOD-BT 
  receives as a server and reacts to certain 
  characters.

  The example prints all characters sent to the board
  via the SPP (serial bluetooth). It detects "1" and 
  "2" and if they are present toggles the on-board
  LEDs.

  '1' toggles LED1
  '2' toggles LED2

  Connect the boards together. IMPORTANT! Make sure 
  the orientation of the module is correct (it is
  possible to connect it revers). Then plug the mini
  USB and upload the code to the board.

  To send characters to the board you would need
  an application capable of bluetooth serial 
  connection. We used a free app called "Bluetooth
  Terminal" from the Google Play Store.

  In the app select to "Connect a device - Insecure"
  and pair with "OLIMEX MOD-BT". The pairing code
  is 0000.
  
  If you have any questions, email:
  
  support@olimex.com
  https://www.olimex.com
  April 2016
*/

#include "Bluetooth.h"

// IMPORTANT! OLIMEXINO-32U4 has two serial ports.
// The example might not work with boards with just
// one serial port. 

void setup(){

  //Set the pins responsible for the LEDs 
  pinMode(7, OUTPUT);    //Init LED1
  pinMode(9, OUTPUT);    //Init LED2
  digitalWrite(7, LOW);  //Turn off LED1
  digitalWrite(9, LOW);   //Turn off LED2

  //Turn on UEXT powering
  pinMode (8, OUTPUT);
  digitalWrite (8, LOW);
  delay (1000);
  
  //Open serial connections to UEXT
  //serial is the virtual serial port created by the USB
  Serial.begin(115200);
  //serial1 is the serial port of the UEXT
  Serial1.begin(115200);
  
  //Init; 115200 is the rate at which other devices should connect to MOD-BT.
  BT_init(115200);
  
  //Disable the echo
  BT_echoOff();
  		
  //Allow other devices to auto-connect to MOD-BT
  BT_setAutoConnection();
  		
  //Start the server
  BT_start();
}

void loop(){
  
 // Read a single character from the serial communication
 // with another bluetooth device. We have configured
 // MOD-BT in setup() to act as a server and the serial communication
 // will start automatically once another device connects to it.
 // For eaxmple: A PC+Bluetooth usb stick; the bluetooth
 // software on the PC creates a COM port, where you can send
 // characters directly to MOD-BT, which in turn sends them to the Arduino
 // via the UEXT connection.
 
  char c;
  
  while(!Serial1.available());
  
  c = Serial1.read();
  Serial.write(c);
  delay (10);
  
  switch(c)
  {
    case '1': 
         digitalWrite(7, digitalRead(7)^1);
         Serial.print("\nGreen LED toggled\n");
         break;
    case '2':
         digitalWrite(9, digitalRead( 9)^1);
         Serial.print("\nYellow LED toggled\n");
         break;		
  };
  
}
